@@ -1,6 +1,7 @@
 mod config;
 mod decimal;
 mod error;
+mod http_client;
 mod quote;
 mod time;
 mod trade;
@@ -15,6 +16,7 @@ fn longbridge(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     openapi.add_class::<config::Config>()?;
     openapi.add_class::<types::Language>()?;
     openapi.add_class::<types::Market>()?;
+    openapi.add_class::<http_client::HttpClient>()?;
     quote::register_types(openapi)?;
     trade::register_types(openapi)?;
 
